os-brick |release| Documenation
===============================

Overview
--------
**os-brick** is a Python package containing classes that help
with volume discovery and removal from a host.

:doc:`installation`
  Instructions on how to get the distribution.

:doc:`tutorial`
  Start here for a quick overview.

:doc:`api/index`
  The complete API Documenation, organized by module.


Changes
-------
see the :doc:`changelog` for a full list of changes to **os-brick**.

About This Documentation
------------------------
This documentation is generated using the `Sphinx
<http://sphinx.pocoo.org/>`_ documentation generator. The source files
for the documentation are located in the *doc/* directory of the
**os-brick** distribution. To generate the docs locally run the
following command from the root directory of the **os-brick** source.

.. code-block:: bash

   $ python setup.py doc


.. toctree::
   :hidden:

   installation
   tutorial
   changelog
   api/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
